summaryrefslogtreecommitdiffhomepage
path: root/mixgtk/mixgtk_mixal.h
diff options
context:
space:
mode:
Diffstat (limited to 'mixgtk/mixgtk_mixal.h')
-rw-r--r--mixgtk/mixgtk_mixal.h24
1 files changed, 19 insertions, 5 deletions
diff --git a/mixgtk/mixgtk_mixal.h b/mixgtk/mixgtk_mixal.h
index 89ef52a..eaf0e23 100644
--- a/mixgtk/mixgtk_mixal.h
+++ b/mixgtk/mixgtk_mixal.h
@@ -1,7 +1,7 @@
/* -*-c-*- ---------------- mixgtk_mixal.h :
* Declarations for functions displaying the mixal source file
* ------------------------------------------------------------------
- * Last change: Time-stamp: <01/03/31 01:02:31 jose>
+ * Last change: Time-stamp: <2001-04-21 23:54:18 jao>
* ------------------------------------------------------------------
* Copyright (C) 2001 Free Software Foundation, Inc.
*
@@ -28,16 +28,30 @@
#include <gtk/gtk.h>
#include <mixlib/mix_vm.h>
+/* the possible colorised elements */
+typedef enum {
+ MIXAL_LINE_BREAK,
+ MIXAL_LINE_LOC,
+ MIXAL_LINE_PLAIN
+} mixal_line_t;
+
+typedef enum {
+ MIXAL_LINE_BG,
+ MIXAL_LINE_FG
+} mixal_line_zone_t;
+
+
/* initialise the mixal widget */
extern gboolean
mixgtk_mixal_init (mix_vm_t *vm);
/* set the location pointer and break colors */
extern void
-mixgtk_mixal_set_loc_color (GdkColor *bg, GdkColor *fg);
+mixgtk_mixal_set_color (mixal_line_t line, mixal_line_zone_t zone,
+ const GdkColor *color);
-extern void
-mixgtk_mixal_set_break_color (GdkColor *bg, GdkColor *fg);
+extern const GdkColor *
+mixgtk_mixal_get_color (mixal_line_t line, mixal_line_zone_t zone);
/* load the corresponding mixal file */
@@ -28,16 +28,30 @@
extern gboolean
mixgtk_mixal_init (mix_vm_t *vm);
-/* set the location pointer and break colors */
+/* set the plain, location pointer and break colors */
extern void